angular.module('gaugesScreen', [])
	.controller('GaugesScreenController', function($scope, $window) {
		var tempUnit = null
		var lengthUnit = null
		const RAD2DEG = (180 / Math.PI)
		const MAX_RPM = 10000
		const BASE_ROTATION = -135
		const MAX_ROTATION = 90
		const MIDDLE_TRANSFORM = "translateX(-50%) translateY(-50%)"

		$scope.data = {}
		// overwriting plain javascript function so we can access from within the controller

		$window.setUnits = (data) => {
			tempUnit = data.tempUnit
			lengthUnit = data.lengthUnit
		}

		$window.toFahrenheit = (pTemp) => (pTemp * 1.8 + 32).toFixed(0)

		function applyNeedleRotation(pRPM) {
			var lNeedle = document.getElementById('gaugeDisplayNeedle')
			var lRotation = (BASE_ROTATION + (pRPM / MAX_RPM) * (MAX_ROTATION - BASE_ROTATION))
			applyDegRotation(lRotation, lNeedle)
		}

		function applyDegRotation(pDeg, pTarget) {
			pTarget.style.transform = MIDDLE_TRANSFORM + 'rotate(' + pDeg + 'deg)'
		}

		$window.updateData = (data) => {
			$scope.$evalAsync(function() {
				// // We need access to the efficiency bar svg element so that we can animate it
				// var eff = document.getElementById("efficiency")
				// value = data.fuelDisplay
				// // dash array needs to be the same as the circumference of the circle (radius * 2 * PI)
				// eff.style.strokeDasharray = 342
				//
				// if (value > 0) {
				// 	// We need to add the value to the negative circumference of the circle so that we can fill up the bar
				// 	eff.style.strokeDashoffset = -342 + value.toFixed(2) * 23
				// 	eff.style.stroke = "#BD362F"
				// } else {
				// 	eff.style.strokeDashoffset = -342 + value.toFixed(2) * 23
				// 	eff.style.stroke = "#295AAC"
				// }

				pitchDegrees = Math.asin(data.pitch) * RAD2DEG
				rollDegrees = Math.asin(data.roll) * RAD2DEG
				$scope.data.pitchDegrees = pitchDegrees.toFixed(1) + " °"
				$scope.data.rollDegrees = rollDegrees.toFixed(1) + " °"

				applyDegRotation(pitchDegrees, document.getElementById('pitchDisplay'))
				applyDegRotation(rollDegrees, document.getElementById('rollDisplay'))

				if (data.gear === -1) {
					$scope.data.gear = "R"
				} else if (data.gear === 0) {
					$scope.data.gear = "N"
				} else if (data.gear.substr(-1) === "1") {
					$scope.data.gear = data.gear + "st"
				} else if (data.gear.substr(-1) === "2") {
					$scope.data.gear = data.gear + "nd"
				} else if (data.gear === "") {
					$scope.data.gear = "---"
				} else {
					$scope.data.gear = data.gear
				}

				applyNeedleRotation(data.rpm)
				$scope.data.rpm = data.rpm.toFixed(0)
				$scope.data.time = data.time

				if (tempUnit === 'c') {
					$scope.data.tempUnit = "°C"
					$scope.data.engineBlockTemperature = data.engineBlockTemperature === undefined ? "---" : data.engineBlockTemperature.toFixed(0)
					$scope.data.exhaustTemperature = data.exhaustTemperature === undefined ? "---" : data.exhaustTemperature.toFixed(0)
				} else {
					$scope.data.tempUnit = "°F"
					$scope.data.engineBlockTemperature = data.engineBlockTemperature === undefined ? "---" : toFahrenheit(data.engineBlockTemperature)
					$scope.data.exhaustTemperature = data.exhaustTemperature === undefined ? "---" : toFahrenheit(data.exhaustTemperature)
				}

				// checking if metric gauge cluster is being used
				if (lengthUnit === "metric") {
					// $scope.data.tempUnit = "°C"
					// $scope.data.speedVal = (data.speed * 3.6).toFixed(0)
					// $scope.data.speedUnit = "km/h"
					// $scope.data.engineBlockTemperature = data.engineBlockTemperature.toFixed(0)
					// $scope.data.exhaustTemperature = data.exhaustTemperature.toFixed(0)
					// if (data.temp.toFixed(1) > 99.9 || data.temp.toFixed(1) < -99.9) {
					// 	$scope.data.temp = "---°C"
					// } else {
					// 	$scope.data.temp = data.temp.toFixed(1) + "°C"
					// }
					if (data.averageFuelConsumption === 0) {
						$scope.data.consumptionVal = "---"
					} else {
						$scope.data.consumptionVal = data.averageFuelConsumption.toFixed(1)
					}
					$scope.data.consumptionUnit = "l/100km"
				} else {
					// $scope.data.tempUnit = "°F"
					// $scope.data.speedVal = (data.speed * 2.23694).toFixed(0)
					// $scope.data.speedUnit = "mph"
					// $scope.data.engineBlockTemperature = toFahrenheit(data.engineBlockTemperature)
					// $scope.data.exhaustTemperature = toFahrenheit(data.exhaustTemperature)
					// $scope.data.temp = toFahrenheit(data.temp) + "°F"
					if (data.averageFuelConsumption === 0) {
						$scope.data.consumptionVal = "---"
					} else {
						$scope.data.consumptionVal = (235 / data.averageFuelConsumption).toFixed(1)
					}
					$scope.data.consumptionUnit = "mpg"
					// A bit ugly but need to set the markers on the SVG for imperial or metric units
					// document.getElementById('markOne').textContent = "30"
					// document.getElementById('markTwo').textContent = "20"
					// document.getElementById('markThree').textContent = "10"
					// document.getElementById('markFour').textContent = "0"
				}
			})
		}
	})
